import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { Automation, AutomationCreatedEnvelope, AutomationDeletedEnvelope, AutomationDeletedWithEntityEnvelope, AutomationNonNullableFields, AutomationUpdatedEnvelope, AutomationUpdatedWithPreviousEntityEnvelope, AutomationsQueryBuilder, BulkDeleteAutomationsResponse, BulkDeleteAutomationsResponseNonNullableFields, CopyAutomationOptions, CopyAutomationResponse, CopyAutomationResponseNonNullableFields, CreateAutomationOptions, CreateDraftAutomationOptions, CreateDraftAutomationResponse, CreateDraftAutomationResponseNonNullableFields, CreatePreinstalledAutomationOptions, CreatePreinstalledAutomationResponse, CreatePreinstalledAutomationResponseNonNullableFields, DeletePreinstalledAutomationOptions, GetActionsQuotaInfoResponse, GetActionsQuotaInfoResponseNonNullableFields, GetAutomationActionSchemaIdentifiers, GetAutomationActionSchemaResponse, GetAutomationOptions, GetOrCreateDraftAutomationOptions, GetOrCreateDraftAutomationResponse, GetOrCreateDraftAutomationResponseNonNullableFields, PublishDraftAutomationOptions, PublishDraftAutomationResponse, PublishDraftAutomationResponseNonNullableFields, QueryAutomationsOptions, QueryAutomationsWithDraftsOptions, QueryAutomationsWithDraftsResponse, QueryAutomationsWithDraftsResponseNonNullableFields, QueryPreinstalledAutomationsForAppOptions, QueryPreinstalledAutomationsForAppResponse, QueryPreinstalledAutomationsForAppResponseNonNullableFields, UpdateAutomation, UpdateAutomationOptions, UpdateDraftAutomation, UpdateDraftAutomationOptions, UpdateDraftAutomationResponse, UpdateDraftAutomationResponseNonNullableFields, UpdatePreinstalledAutomationOptions, UpdatePreinstalledAutomationResponse, UpdatePreinstalledAutomationResponseNonNullableFields, ValidateAutomationByIdOptions, ValidateAutomationByIdResponse, ValidateAutomationByIdResponseNonNullableFields, ValidateAutomationOptions, ValidateAutomationResponse, ValidateAutomationResponseNonNullableFields } from './automations-v2-automation-automations-service-v-2.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function createAutomation(httpClient: HttpClient): CreateAutomationSignature;
interface CreateAutomationSignature {
    /**
     * Creates an automation.
     * @param - Automation to be created.
     * @returns The created automation.
     */
    (automation: Automation, options?: CreateAutomationOptions | undefined): Promise<Automation & AutomationNonNullableFields>;
}
export declare function getAutomation(httpClient: HttpClient): GetAutomationSignature;
interface GetAutomationSignature {
    /**
     * Retrieves an automation.
     * @param - Automation ID.
     * @returns The requested automation.
     */
    (automationId: string, options?: GetAutomationOptions | undefined): Promise<Automation & AutomationNonNullableFields>;
}
export declare function updateAutomation(httpClient: HttpClient): UpdateAutomationSignature;
interface UpdateAutomationSignature {
    /**
     * Updates an automation.
     *
     * Each time the automation is updated,
     * `revision` increments by 1.
     * The current `revision` must be passed when updating the automation.
     * This ensures you're working with the latest automation
     * and prevents unintended overwrites.
     * @param - Automation ID.
     * @returns Updated automation.
     */
    (_id: string | null, automation: UpdateAutomation, options?: UpdateAutomationOptions | undefined): Promise<Automation & AutomationNonNullableFields>;
}
export declare function deleteAutomation(httpClient: HttpClient): DeleteAutomationSignature;
interface DeleteAutomationSignature {
    /**
     * Deletes an Automation.
     * @param - Automation ID.
     */
    (automationId: string): Promise<void>;
}
export declare function bulkDeleteAutomations(httpClient: HttpClient): BulkDeleteAutomationsSignature;
interface BulkDeleteAutomationsSignature {
    /**
     * Deletes multiple automations.
     * @param - Automation IDs to delete.
     */
    (automationIds: string[]): Promise<BulkDeleteAutomationsResponse & BulkDeleteAutomationsResponseNonNullableFields>;
}
export declare function createPreinstalledAutomation(httpClient: HttpClient): CreatePreinstalledAutomationSignature;
interface CreatePreinstalledAutomationSignature {
    /**
     * We have a special identification mechanism here with Dev Center.
     * @param - Preinstalled automation to be created.
     */
    (automation: Automation, options?: CreatePreinstalledAutomationOptions | undefined): Promise<CreatePreinstalledAutomationResponse & CreatePreinstalledAutomationResponseNonNullableFields>;
}
export declare function updatePreinstalledAutomation(httpClient: HttpClient): UpdatePreinstalledAutomationSignature;
interface UpdatePreinstalledAutomationSignature {
    /**
     * We have a special identification mechanism here with Dev Center.
     * @param - Preinstalled automation to update.
     */
    (automation: Automation, options?: UpdatePreinstalledAutomationOptions | undefined): Promise<UpdatePreinstalledAutomationResponse & UpdatePreinstalledAutomationResponseNonNullableFields>;
}
export declare function deletePreinstalledAutomation(httpClient: HttpClient): DeletePreinstalledAutomationSignature;
interface DeletePreinstalledAutomationSignature {
    /**
     * We have a special identification mechanism here with Dev Center.
     * @param - Preinstalled Component Id
     */
    (componentId: string, options?: DeletePreinstalledAutomationOptions | undefined): Promise<void>;
}
export declare function queryPreinstalledAutomationsForApp(httpClient: HttpClient): QueryPreinstalledAutomationsForAppSignature;
interface QueryPreinstalledAutomationsForAppSignature {
    /**
     * We have a special identification mechanism here with Dev Center.
     */
    (options?: QueryPreinstalledAutomationsForAppOptions | undefined): Promise<QueryPreinstalledAutomationsForAppResponse & QueryPreinstalledAutomationsForAppResponseNonNullableFields>;
}
export declare function queryAutomations(httpClient: HttpClient): QueryAutomationsSignature;
interface QueryAutomationsSignature {
    /**
     * Retrieves a list of automations. Max query filter depth is 3.
     *
     * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
     * If there's an existing override for a pre-installed automation, the override is returned in the query result.
     * The query only returns automations from apps that are installed on the site.
     *
     * To learn about working with _Query_ endpoints, see
     * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
     * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
     * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
     */
    (options?: QueryAutomationsOptions | undefined): AutomationsQueryBuilder;
}
export declare function copyAutomation(httpClient: HttpClient): CopyAutomationSignature;
interface CopyAutomationSignature {
    /**
     * Creates a copy of an action with a new ID, and changes the action's input mapping if necessary.
     *
     * The action copy isn't saved automatically. To save it, the user must perform an action
     * such as clicking the **Save** button.
     * @param - Automation ID.
     */
    (automationId: string, options?: CopyAutomationOptions | undefined): Promise<CopyAutomationResponse & CopyAutomationResponseNonNullableFields>;
}
export declare function createDraftAutomation(httpClient: HttpClient): CreateDraftAutomationSignature;
interface CreateDraftAutomationSignature {
    /**
     * Creates a draft automation.
     */
    (options?: CreateDraftAutomationOptions | undefined): Promise<CreateDraftAutomationResponse & CreateDraftAutomationResponseNonNullableFields>;
}
export declare function getOrCreateDraftAutomation(httpClient: HttpClient): GetOrCreateDraftAutomationSignature;
interface GetOrCreateDraftAutomationSignature {
    /**
     * Gets the draft of the given original automation if exists, or creates one and returns it
     *
     * - if the original automation is a draft, returns the original automation
     * @param - Original automation id
     */
    (originalAutomationId: string, options?: GetOrCreateDraftAutomationOptions | undefined): Promise<GetOrCreateDraftAutomationResponse & GetOrCreateDraftAutomationResponseNonNullableFields>;
}
export declare function updateDraftAutomation(httpClient: HttpClient): UpdateDraftAutomationSignature;
interface UpdateDraftAutomationSignature {
    /**
     * Updates a draft automation
     * @param - Automation ID.
     */
    (_id: string | null, automation: UpdateDraftAutomation, options?: UpdateDraftAutomationOptions | undefined): Promise<UpdateDraftAutomationResponse & UpdateDraftAutomationResponseNonNullableFields>;
}
export declare function queryAutomationsWithDrafts(httpClient: HttpClient): QueryAutomationsWithDraftsSignature;
interface QueryAutomationsWithDraftsSignature {
    /**
     * Retrieves a list of automations including drafts. Max query filter depth is 3.
     *
     * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
     * If there's an existing override for a pre-installed automation, the override is returned in the query result.
     * The query only returns automations from apps that are installed on the site.
     *
     * - new drafts that are not related to existing automations will be returned in the list
     * - the response will contain a map of originalAutomationId => relatedDrafts
     *
     * To learn about working with _Query_ endpoints, see
     * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
     * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
     * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
     */
    (options?: QueryAutomationsWithDraftsOptions | undefined): Promise<QueryAutomationsWithDraftsResponse & QueryAutomationsWithDraftsResponseNonNullableFields>;
}
export declare function deleteDraftAutomation(httpClient: HttpClient): DeleteDraftAutomationSignature;
interface DeleteDraftAutomationSignature {
    /**
     * Deletes a draft automation.
     * @param - Id of the draft automation to delete.
     */
    (automationId: string): Promise<void>;
}
export declare function publishDraftAutomation(httpClient: HttpClient): PublishDraftAutomationSignature;
interface PublishDraftAutomationSignature {
    /**
     * Publishes a draft automation, applying the changes to live automation
     * @param - Id of the draft automation to publish.
     */
    (automationId: string, options?: PublishDraftAutomationOptions | undefined): Promise<PublishDraftAutomationResponse & PublishDraftAutomationResponseNonNullableFields>;
}
export declare function validateAutomation(httpClient: HttpClient): ValidateAutomationSignature;
interface ValidateAutomationSignature {
    /**
     * Validates the automation without requiring the automation ID to be passed in.
     * @param - Automation to validate.
     */
    (automation: Automation, options?: ValidateAutomationOptions | undefined): Promise<ValidateAutomationResponse & ValidateAutomationResponseNonNullableFields>;
}
export declare function validateAutomationById(httpClient: HttpClient): ValidateAutomationByIdSignature;
interface ValidateAutomationByIdSignature {
    /**
     * Validate Automation by automation ID
     * @param - Automation ID
     */
    (automationId: string, options?: ValidateAutomationByIdOptions | undefined): Promise<ValidateAutomationByIdResponse & ValidateAutomationByIdResponseNonNullableFields>;
}
export declare function getAutomationActionSchema(httpClient: HttpClient): GetAutomationActionSchemaSignature;
interface GetAutomationActionSchemaSignature {
    /**
     * Gets the payload schema received by the action whose ID is passed in.
     */
    (identifiers: GetAutomationActionSchemaIdentifiers): Promise<GetAutomationActionSchemaResponse>;
}
export declare function getActionsQuotaInfo(httpClient: HttpClient): GetActionsQuotaInfoSignature;
interface GetActionsQuotaInfoSignature {
    /**
     * Gets action quota information.
     */
    (): Promise<GetActionsQuotaInfoResponse & GetActionsQuotaInfoResponseNonNullableFields>;
}
export declare const onAutomationCreated: EventDefinition<AutomationCreatedEnvelope, "wix.automations.v2.automation_created">;
export declare const onAutomationDeleted: EventDefinition<AutomationDeletedEnvelope, "wix.automations.v2.automation_deleted">;
export declare const onAutomationDeletedWithEntity: EventDefinition<AutomationDeletedWithEntityEnvelope, "wix.automations.v2.automation_deleted_with_entity">;
export declare const onAutomationUpdated: EventDefinition<AutomationUpdatedEnvelope, "wix.automations.v2.automation_updated">;
export declare const onAutomationUpdatedWithPreviousEntity: EventDefinition<AutomationUpdatedWithPreviousEntityEnvelope, "wix.automations.v2.automation_updated_with_previous_entity">;
export { Action, ActionConfigurationError, ActionErrorType, ActionEvent, ActionInfoOneOf, ActionProviderQuotaInfo, ActionQuotaInfo, ActionSettings, ActionUsageSummary, ActionValidationError, ActionValidationErrorErrorOneOf, ActionValidationInfo, AdditionalInfo, AppDefinedAction, ApplicationError, ApplicationOrigin, Asset, AuditInfo, AuditInfoIdOneOf, Automation, AutomationConfiguration, AutomationConfigurationError, AutomationCreatedEnvelope, AutomationDeletedEnvelope, AutomationDeletedWithEntityEnvelope, AutomationErrorType, AutomationNonNullableFields, AutomationOriginInfoOneOf, AutomationSettings, AutomationUpdatedEnvelope, AutomationUpdatedWithPreviousEntityEnvelope, AutomationValidationError, AutomationValidationErrorErrorOneOf, AutomationValidationErrorValidationErrorType, AutomationsQueryBuilder, AutomationsQueryResult, BaseEventMetadata, BulkActionMetadata, BulkDeleteAutomationsRequest, BulkDeleteAutomationsResponse, BulkDeleteAutomationsResponseNonNullableFields, BulkDeleteResult, CTA, ConditionAction, ConditionExpressionGroup, CopyAutomationOptions, CopyAutomationRequest, CopyAutomationResponse, CopyAutomationResponseNonNullableFields, CreateAutomationOptions, CreateAutomationRequest, CreateAutomationResponse, CreateAutomationResponseNonNullableFields, CreateDraftAutomationOptions, CreateDraftAutomationRequest, CreateDraftAutomationResponse, CreateDraftAutomationResponseNonNullableFields, CreatePreinstalledAutomationOptions, CreatePreinstalledAutomationRequest, CreatePreinstalledAutomationResponse, CreatePreinstalledAutomationResponseNonNullableFields, CursorPaging, CursorPagingMetadata, CursorQuery, CursorQueryPagingMethodOneOf, Cursors, DelayAction, DeleteAutomationRequest, DeleteAutomationResponse, DeleteContext, DeleteDraftAutomationRequest, DeleteDraftAutomationResponse, DeletePreinstalledAutomationOptions, DeletePreinstalledAutomationRequest, DeletePreinstalledAutomationResponse, DeleteStatus, DeletedWithEntity, Domain, DomainEvent, DomainEventBodyOneOf, DraftInfo, DraftPublished, DraftsInfo, Empty, Enrichment, Enrichments, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, ExtendedFields, Filter, FilterValueSelection, FilterableAppDefinedActions, FutureDateActivationOffset, GeneratePreinstalledAutomationRequest, GeneratePreinstalledAutomationResponse, GetActionsQuotaInfoRequest, GetActionsQuotaInfoResponse, GetActionsQuotaInfoResponseNonNullableFields, GetAggregatedUsageInfoRequest, GetAggregatedUsageInfoResponse, GetAutomationActionSchemaIdentifiers, GetAutomationActionSchemaRequest, GetAutomationActionSchemaResponse, GetAutomationOptions, GetAutomationRequest, GetAutomationResponse, GetAutomationResponseNonNullableFields, GetAutomationRevisionOptions, GetAutomationRevisionRequest, GetAutomationRevisionResponse, GetAutomationRevisionResponseNonNullableFields, GetOrCreateDraftAutomationOptions, GetOrCreateDraftAutomationRequest, GetOrCreateDraftAutomationResponse, GetOrCreateDraftAutomationResponseNonNullableFields, IdentificationData, IdentificationDataIdOneOf, ItemMetadata, MessageEnvelope, MetaSiteSpecialEvent, MetaSiteSpecialEventPayloadOneOf, MigrateVeloActionAutomationsRequest, MigrateVeloActionAutomationsResponse, Namespace, NamespaceChanged, Operator, Origin, OriginAutomationInfo, OutputAction, Plan, PreinstalledAutomationSpecInfo, PreinstalledOrigin, ProviderConfigurationError, PublishDraftAutomationOptions, PublishDraftAutomationRequest, PublishDraftAutomationResponse, PublishDraftAutomationResponseNonNullableFields, QueryAutomationsOptions, QueryAutomationsRequest, QueryAutomationsResponse, QueryAutomationsResponseNonNullableFields, QueryAutomationsWithDraftsOptions, QueryAutomationsWithDraftsRequest, QueryAutomationsWithDraftsResponse, QueryAutomationsWithDraftsResponseNonNullableFields, QueryPreinstalledAutomationsForAppOptions, QueryPreinstalledAutomationsForAppRequest, QueryPreinstalledAutomationsForAppResponse, QueryPreinstalledAutomationsForAppResponseNonNullableFields, Quota, QuotaInfo, RateLimit, RateLimitAction, RequestedFields, RestoreInfo, ServiceProvisioned, ServiceRemoved, SetVariablesAction, SiteCreated, SiteCreatedContext, SiteDeleted, SiteHardDeleted, SiteMarkedAsTemplate, SiteMarkedAsWixSite, SitePublished, SiteRenamed, SiteTransferred, SiteUndeleted, SiteUnpublished, SiteUrlChanged, SortOrder, Sorting, State, Status, StudioAssigned, StudioUnassigned, TimeUnit, Trigger, TriggerConfigurationError, TriggerErrorType, TriggerUsageSummary, TriggerValidationError, TriggerValidationErrorErrorOneOf, TriggerValidationErrorValidationErrorType, Type, UpdateAutomation, UpdateAutomationOptions, UpdateAutomationRequest, UpdateAutomationResponse, UpdateAutomationResponseNonNullableFields, UpdateDraftAutomation, UpdateDraftAutomationOptions, UpdateDraftAutomationRequest, UpdateDraftAutomationResponse, UpdateDraftAutomationResponseNonNullableFields, UpdatePreinstalledAutomationOptions, UpdatePreinstalledAutomationRequest, UpdatePreinstalledAutomationResponse, UpdatePreinstalledAutomationResponseNonNullableFields, UpdatedWithPreviousEntity, UpgradeCTA, ValidateAutomationByIdOptions, ValidateAutomationByIdRequest, ValidateAutomationByIdResponse, ValidateAutomationByIdResponseNonNullableFields, ValidateAutomationOptions, ValidateAutomationRequest, ValidateAutomationResponse, ValidateAutomationResponseNonNullableFields, ValidationErrorSeverity, ValidationErrorType, ValidationSettings, WebhookIdentityType, } from './automations-v2-automation-automations-service-v-2.universal.js';
