import { RequestOptionsFactory } from '@wix/sdk-types';
/** Creates an automation. */
export declare function createAutomation(payload: object): RequestOptionsFactory<any>;
/** Retrieves an automation. */
export declare function getAutomation(payload: object): RequestOptionsFactory<any>;
/**
 * Updates an automation.
 *
 * Each time the automation is updated,
 * `revision` increments by 1.
 * The current `revision` must be passed when updating the automation.
 * This ensures you're working with the latest automation
 * and prevents unintended overwrites.
 */
export declare function updateAutomation(payload: object): RequestOptionsFactory<any>;
/** Deletes an Automation. */
export declare function deleteAutomation(payload: object): RequestOptionsFactory<any>;
/** Deletes multiple automations. */
export declare function bulkDeleteAutomations(payload: object): RequestOptionsFactory<any>;
/** We have a special identification mechanism here with Dev Center. */
export declare function createPreinstalledAutomation(payload: object): RequestOptionsFactory<any>;
/** We have a special identification mechanism here with Dev Center. */
export declare function updatePreinstalledAutomation(payload: object): RequestOptionsFactory<any>;
/** We have a special identification mechanism here with Dev Center. */
export declare function deletePreinstalledAutomation(payload: object): RequestOptionsFactory<any>;
/** We have a special identification mechanism here with Dev Center. */
export declare function queryPreinstalledAutomationsForApp(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of automations. Max query filter depth is 3.
 *
 * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
 * If there's an existing override for a pre-installed automation, the override is returned in the query result.
 * The query only returns automations from apps that are installed on the site.
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 */
export declare function queryAutomations(payload: object): RequestOptionsFactory<any>;
/**
 * Creates a copy of an action with a new ID, and changes the action's input mapping if necessary.
 *
 * The action copy isn't saved automatically. To save it, the user must perform an action
 * such as clicking the **Save** button.
 */
export declare function copyAutomation(payload: object): RequestOptionsFactory<any>;
/** Creates a draft automation. */
export declare function createDraftAutomation(payload: object): RequestOptionsFactory<any>;
/**
 * Gets the draft of the given original automation if exists, or creates one and returns it
 *
 * - if the original automation is a draft, returns the original automation
 */
export declare function getOrCreateDraftAutomation(payload: object): RequestOptionsFactory<any>;
/** Updates a draft automation */
export declare function updateDraftAutomation(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a list of automations including drafts. Max query filter depth is 3.
 *
 * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
 * If there's an existing override for a pre-installed automation, the override is returned in the query result.
 * The query only returns automations from apps that are installed on the site.
 *
 * - new drafts that are not related to existing automations will be returned in the list
 * - the response will contain a map of originalAutomationId => relatedDrafts
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 */
export declare function queryAutomationsWithDrafts(payload: object): RequestOptionsFactory<any>;
/** Deletes a draft automation. */
export declare function deleteDraftAutomation(payload: object): RequestOptionsFactory<any>;
/** Publishes a draft automation, applying the changes to live automation */
export declare function publishDraftAutomation(payload: object): RequestOptionsFactory<any>;
/** Validates the automation without requiring the automation ID to be passed in. */
export declare function validateAutomation(payload: object): RequestOptionsFactory<any>;
/** Validate Automation by automation ID */
export declare function validateAutomationById(payload: object): RequestOptionsFactory<any>;
/** Gets the payload schema received by the action whose ID is passed in. */
export declare function getAutomationActionSchema(payload: object): RequestOptionsFactory<any>;
/** Gets action quota information. */
export declare function getActionsQuotaInfo(payload: object): RequestOptionsFactory<any>;
/** Get automation revision */
export declare function getAutomationRevision(payload: object): RequestOptionsFactory<any>;
