"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAutomationRevision = exports.getActionsQuotaInfo = exports.getAutomationActionSchema = exports.validateAutomationById = exports.validateAutomation = exports.publishDraftAutomation = exports.deleteDraftAutomation = exports.queryAutomationsWithDrafts = exports.updateDraftAutomation = exports.getOrCreateDraftAutomation = exports.createDraftAutomation = exports.copyAutomation = exports.queryAutomations = exports.queryPreinstalledAutomationsForApp = exports.deletePreinstalledAutomation = exports.updatePreinstalledAutomation = exports.createPreinstalledAutomation = exports.bulkDeleteAutomations = exports.deleteAutomation = exports.updateAutomation = exports.getAutomation = exports.createAutomation = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const timestamp_2 = require("@wix/sdk-runtime/transformations/timestamp");
const field_mask_1 = require("@wix/sdk-runtime/transformations/field-mask");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveWixAutomationsV2AutomationRevisionsServiceUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/automations-service',
                destPath: '',
            },
            {
                srcPath: '/_api/automations-service',
                destPath: '/api',
            },
        ],
        'platform.rise.ai': [
            {
                srcPath: '/v2/automations',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
function resolveWixAutomationsV2AutomationsServiceUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/automations-service',
                destPath: '',
            },
            {
                srcPath: '/_api/automations-service',
                destPath: '/api',
            },
        ],
        'platform.rise.ai': [
            {
                srcPath: '/v2/automations',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_automations_automations-service-v-2';
/** Creates an automation. */
function createAutomation(payload) {
    function __createAutomation({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.CreateAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createAutomation;
}
exports.createAutomation = createAutomation;
/** Retrieves an automation. */
function getAutomation(payload) {
    function __getAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'GET',
            methodFqn: 'wix.automations.v2.AutomationsService.GetAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automationId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getAutomation;
}
exports.getAutomation = getAutomation;
/**
 * Updates an automation.
 *
 * Each time the automation is updated,
 * `revision` increments by 1.
 * The current `revision` must be passed when updating the automation.
 * This ensures you're working with the latest automation
 * and prevents unintended overwrites.
 */
function updateAutomation(payload) {
    function __updateAutomation({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: field_mask_1.transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'fieldMask' }],
            },
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'PATCH',
            methodFqn: 'wix.automations.v2.AutomationsService.UpdateAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automation.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateAutomation;
}
exports.updateAutomation = updateAutomation;
/** Deletes an Automation. */
function deleteAutomation(payload) {
    function __deleteAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'DELETE',
            methodFqn: 'wix.automations.v2.AutomationsService.DeleteAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automationId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deleteAutomation;
}
exports.deleteAutomation = deleteAutomation;
/** Deletes multiple automations. */
function bulkDeleteAutomations(payload) {
    function __bulkDeleteAutomations({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.BulkDeleteAutomations',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/bulk/automations/delete',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkDeleteAutomations;
}
exports.bulkDeleteAutomations = bulkDeleteAutomations;
/** We have a special identification mechanism here with Dev Center. */
function createPreinstalledAutomation(payload) {
    function __createPreinstalledAutomation({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.CreatePreinstalledAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/preinstalled-automation',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createPreinstalledAutomation;
}
exports.createPreinstalledAutomation = createPreinstalledAutomation;
/** We have a special identification mechanism here with Dev Center. */
function updatePreinstalledAutomation(payload) {
    function __updatePreinstalledAutomation({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'PATCH',
            methodFqn: 'wix.automations.v2.AutomationsService.UpdatePreinstalledAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/preinstalled-automation',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updatePreinstalledAutomation;
}
exports.updatePreinstalledAutomation = updatePreinstalledAutomation;
/** We have a special identification mechanism here with Dev Center. */
function deletePreinstalledAutomation(payload) {
    function __deletePreinstalledAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'DELETE',
            methodFqn: 'wix.automations.v2.AutomationsService.DeletePreinstalledAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/preinstalled-automation/{componentId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deletePreinstalledAutomation;
}
exports.deletePreinstalledAutomation = deletePreinstalledAutomation;
/** We have a special identification mechanism here with Dev Center. */
function queryPreinstalledAutomationsForApp(payload) {
    function __queryPreinstalledAutomationsForApp({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.QueryPreinstalledAutomationsForApp',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/preinstalled-automations/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automations.createdDate' },
                        { path: 'automations.updatedDate' },
                        { path: 'automations.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryPreinstalledAutomationsForApp;
}
exports.queryPreinstalledAutomationsForApp = queryPreinstalledAutomationsForApp;
/**
 * Retrieves a list of automations. Max query filter depth is 3.
 *
 * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
 * If there's an existing override for a pre-installed automation, the override is returned in the query result.
 * The query only returns automations from apps that are installed on the site.
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 */
function queryAutomations(payload) {
    function __queryAutomations({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.QueryAutomations',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automations.createdDate' },
                        { path: 'automations.updatedDate' },
                        { path: 'automations.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryAutomations;
}
exports.queryAutomations = queryAutomations;
/**
 * Creates a copy of an action with a new ID, and changes the action's input mapping if necessary.
 *
 * The action copy isn't saved automatically. To save it, the user must perform an action
 * such as clicking the **Save** button.
 */
function copyAutomation(payload) {
    function __copyAutomation({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.CopyAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automationId}/copy',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __copyAutomation;
}
exports.copyAutomation = copyAutomation;
/** Creates a draft automation. */
function createDraftAutomation(payload) {
    function __createDraftAutomation({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.CreateDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createDraftAutomation;
}
exports.createDraftAutomation = createDraftAutomation;
/**
 * Gets the draft of the given original automation if exists, or creates one and returns it
 *
 * - if the original automation is a draft, returns the original automation
 */
function getOrCreateDraftAutomation(payload) {
    function __getOrCreateDraftAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.GetOrCreateDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts/get-or-create/original-automation-id/{originalAutomationId}',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getOrCreateDraftAutomation;
}
exports.getOrCreateDraftAutomation = getOrCreateDraftAutomation;
/** Updates a draft automation */
function updateDraftAutomation(payload) {
    function __updateDraftAutomation({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: field_mask_1.transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'fieldMask' }],
            },
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'PATCH',
            methodFqn: 'wix.automations.v2.AutomationsService.UpdateDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts/{automation.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateDraftAutomation;
}
exports.updateDraftAutomation = updateDraftAutomation;
/**
 * Retrieves a list of automations including drafts. Max query filter depth is 3.
 *
 * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
 * If there's an existing override for a pre-installed automation, the override is returned in the query result.
 * The query only returns automations from apps that are installed on the site.
 *
 * - new drafts that are not related to existing automations will be returned in the list
 * - the response will contain a map of originalAutomationId => relatedDrafts
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 */
function queryAutomationsWithDrafts(payload) {
    function __queryAutomationsWithDrafts({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.QueryAutomationsWithDrafts',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/query-with-drafts',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automations.createdDate' },
                        { path: 'automations.updatedDate' },
                        { path: 'automations.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryAutomationsWithDrafts;
}
exports.queryAutomationsWithDrafts = queryAutomationsWithDrafts;
/** Deletes a draft automation. */
function deleteDraftAutomation(payload) {
    function __deleteDraftAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'DELETE',
            methodFqn: 'wix.automations.v2.AutomationsService.DeleteDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts/{automationId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deleteDraftAutomation;
}
exports.deleteDraftAutomation = deleteDraftAutomation;
/** Publishes a draft automation, applying the changes to live automation */
function publishDraftAutomation(payload) {
    function __publishDraftAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.PublishDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts/{automationId}/publish',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __publishDraftAutomation;
}
exports.publishDraftAutomation = publishDraftAutomation;
/** Validates the automation without requiring the automation ID to be passed in. */
function validateAutomation(payload) {
    function __validateAutomation({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.ValidateAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/validate',
                data: serializedData,
                host,
            }),
            data: serializedData,
        };
        return metadata;
    }
    return __validateAutomation;
}
exports.validateAutomation = validateAutomation;
/** Validate Automation by automation ID */
function validateAutomationById(payload) {
    function __validateAutomationById({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.ValidateAutomationById',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automationId}/validate',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __validateAutomationById;
}
exports.validateAutomationById = validateAutomationById;
/** Gets the payload schema received by the action whose ID is passed in. */
function getAutomationActionSchema(payload) {
    function __getAutomationActionSchema({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'GET',
            methodFqn: 'wix.automations.v2.AutomationsService.GetAutomationActionSchema',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/schema/{automationId}/{actionId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __getAutomationActionSchema;
}
exports.getAutomationActionSchema = getAutomationActionSchema;
/** Gets action quota information. */
function getActionsQuotaInfo(payload) {
    function __getActionsQuotaInfo({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'GET',
            methodFqn: 'wix.automations.v2.AutomationsService.GetActionsQuotaInfo',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/actions/quota',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        {
                            path: 'actionProviderQuotaInfo.actionQuotaInfo.quotaInfo.quotas.renewalDate',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getActionsQuotaInfo;
}
exports.getActionsQuotaInfo = getActionsQuotaInfo;
/** Get automation revision */
function getAutomationRevision(payload) {
    function __getAutomationRevision({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'GET',
            methodFqn: 'wix.automations.v2.AutomationRevisionsService.GetAutomationRevision',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationRevisionsServiceUrl({
                protoPath: '/v1/automation-revisions/{automationId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getAutomationRevision;
}
exports.getAutomationRevision = getAutomationRevision;
//# sourceMappingURL=automations-v2-automation-automations-service-v-2.http.js.map