import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformSDKFieldMaskToRESTFieldMask } from '@wix/sdk-runtime/transformations/field-mask';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixAutomationsV2AutomationRevisionsServiceUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/automations-service',
                destPath: '',
            },
            {
                srcPath: '/_api/automations-service',
                destPath: '/api',
            },
        ],
        'platform.rise.ai': [
            {
                srcPath: '/v2/automations',
                destPath: '',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
function resolveWixAutomationsV2AutomationsServiceUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/automations-service',
                destPath: '',
            },
            {
                srcPath: '/_api/automations-service',
                destPath: '/api',
            },
        ],
        'platform.rise.ai': [
            {
                srcPath: '/v2/automations',
                destPath: '',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_automations_automations-service-v-2';
/** Creates an automation. */
export function createAutomation(payload) {
    function __createAutomation({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.CreateAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createAutomation;
}
/** Retrieves an automation. */
export function getAutomation(payload) {
    function __getAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'GET',
            methodFqn: 'wix.automations.v2.AutomationsService.GetAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automationId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getAutomation;
}
/**
 * Updates an automation.
 *
 * Each time the automation is updated,
 * `revision` increments by 1.
 * The current `revision` must be passed when updating the automation.
 * This ensures you're working with the latest automation
 * and prevents unintended overwrites.
 */
export function updateAutomation(payload) {
    function __updateAutomation({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'fieldMask' }],
            },
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'PATCH',
            methodFqn: 'wix.automations.v2.AutomationsService.UpdateAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automation.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateAutomation;
}
/** Deletes an Automation. */
export function deleteAutomation(payload) {
    function __deleteAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'DELETE',
            methodFqn: 'wix.automations.v2.AutomationsService.DeleteAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automationId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __deleteAutomation;
}
/** Deletes multiple automations. */
export function bulkDeleteAutomations(payload) {
    function __bulkDeleteAutomations({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.BulkDeleteAutomations',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/bulk/automations/delete',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __bulkDeleteAutomations;
}
/** We have a special identification mechanism here with Dev Center. */
export function createPreinstalledAutomation(payload) {
    function __createPreinstalledAutomation({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.CreatePreinstalledAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/preinstalled-automation',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createPreinstalledAutomation;
}
/** We have a special identification mechanism here with Dev Center. */
export function updatePreinstalledAutomation(payload) {
    function __updatePreinstalledAutomation({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'PATCH',
            methodFqn: 'wix.automations.v2.AutomationsService.UpdatePreinstalledAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/preinstalled-automation',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updatePreinstalledAutomation;
}
/** We have a special identification mechanism here with Dev Center. */
export function deletePreinstalledAutomation(payload) {
    function __deletePreinstalledAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'DELETE',
            methodFqn: 'wix.automations.v2.AutomationsService.DeletePreinstalledAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/preinstalled-automation/{componentId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __deletePreinstalledAutomation;
}
/** We have a special identification mechanism here with Dev Center. */
export function queryPreinstalledAutomationsForApp(payload) {
    function __queryPreinstalledAutomationsForApp({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.QueryPreinstalledAutomationsForApp',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/preinstalled-automations/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automations.createdDate' },
                        { path: 'automations.updatedDate' },
                        { path: 'automations.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryPreinstalledAutomationsForApp;
}
/**
 * Retrieves a list of automations. Max query filter depth is 3.
 *
 * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
 * If there's an existing override for a pre-installed automation, the override is returned in the query result.
 * The query only returns automations from apps that are installed on the site.
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 */
export function queryAutomations(payload) {
    function __queryAutomations({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.QueryAutomations',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/query',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automations.createdDate' },
                        { path: 'automations.updatedDate' },
                        { path: 'automations.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryAutomations;
}
/**
 * Creates a copy of an action with a new ID, and changes the action's input mapping if necessary.
 *
 * The action copy isn't saved automatically. To save it, the user must perform an action
 * such as clicking the **Save** button.
 */
export function copyAutomation(payload) {
    function __copyAutomation({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.CopyAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automationId}/copy',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __copyAutomation;
}
/** Creates a draft automation. */
export function createDraftAutomation(payload) {
    function __createDraftAutomation({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.CreateDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __createDraftAutomation;
}
/**
 * Gets the draft of the given original automation if exists, or creates one and returns it
 *
 * - if the original automation is a draft, returns the original automation
 */
export function getOrCreateDraftAutomation(payload) {
    function __getOrCreateDraftAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.GetOrCreateDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts/get-or-create/original-automation-id/{originalAutomationId}',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getOrCreateDraftAutomation;
}
/** Updates a draft automation */
export function updateDraftAutomation(payload) {
    function __updateDraftAutomation({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKFieldMaskToRESTFieldMask,
                paths: [{ path: 'fieldMask' }],
            },
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'PATCH',
            methodFqn: 'wix.automations.v2.AutomationsService.UpdateDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts/{automation.id}',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __updateDraftAutomation;
}
/**
 * Retrieves a list of automations including drafts. Max query filter depth is 3.
 *
 * Relevant automations for the query are returned. This includes automations created on the site and pre-installed automations.
 * If there's an existing override for a pre-installed automation, the override is returned in the query result.
 * The query only returns automations from apps that are installed on the site.
 *
 * - new drafts that are not related to existing automations will be returned in the list
 * - the response will contain a map of originalAutomationId => relatedDrafts
 *
 * To learn about working with _Query_ endpoints, see
 * [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language),
 * [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination),
 * and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 */
export function queryAutomationsWithDrafts(payload) {
    function __queryAutomationsWithDrafts({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.QueryAutomationsWithDrafts',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/query-with-drafts',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automations.createdDate' },
                        { path: 'automations.updatedDate' },
                        { path: 'automations.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __queryAutomationsWithDrafts;
}
/** Deletes a draft automation. */
export function deleteDraftAutomation(payload) {
    function __deleteDraftAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'DELETE',
            methodFqn: 'wix.automations.v2.AutomationsService.DeleteDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts/{automationId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __deleteDraftAutomation;
}
/** Publishes a draft automation, applying the changes to live automation */
export function publishDraftAutomation(payload) {
    function __publishDraftAutomation({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.PublishDraftAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/drafts/{automationId}/publish',
                data: payload,
                host,
            }),
            data: payload,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __publishDraftAutomation;
}
/** Validates the automation without requiring the automation ID to be passed in. */
export function validateAutomation(payload) {
    function __validateAutomation({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [
                    { path: 'automation.createdDate' },
                    { path: 'automation.updatedDate' },
                    { path: 'automation.draftUpdatedDate' },
                ],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.ValidateAutomation',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/validate',
                data: serializedData,
                host,
            }),
            data: serializedData,
        };
        return metadata;
    }
    return __validateAutomation;
}
/** Validate Automation by automation ID */
export function validateAutomationById(payload) {
    function __validateAutomationById({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'POST',
            methodFqn: 'wix.automations.v2.AutomationsService.ValidateAutomationById',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/{automationId}/validate',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __validateAutomationById;
}
/** Gets the payload schema received by the action whose ID is passed in. */
export function getAutomationActionSchema(payload) {
    function __getAutomationActionSchema({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'GET',
            methodFqn: 'wix.automations.v2.AutomationsService.GetAutomationActionSchema',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/schema/{automationId}/{actionId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
        };
        return metadata;
    }
    return __getAutomationActionSchema;
}
/** Gets action quota information. */
export function getActionsQuotaInfo(payload) {
    function __getActionsQuotaInfo({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'GET',
            methodFqn: 'wix.automations.v2.AutomationsService.GetActionsQuotaInfo',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationsServiceUrl({
                protoPath: '/v2/automations/actions/quota',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        {
                            path: 'actionProviderQuotaInfo.actionQuotaInfo.quotaInfo.quotas.renewalDate',
                        },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getActionsQuotaInfo;
}
/** Get automation revision */
export function getAutomationRevision(payload) {
    function __getAutomationRevision({ host }) {
        const metadata = {
            entityFqdn: 'wix.automations.v2.automation',
            method: 'GET',
            methodFqn: 'wix.automations.v2.AutomationRevisionsService.GetAutomationRevision',
            packageName: PACKAGE_NAME,
            url: resolveWixAutomationsV2AutomationRevisionsServiceUrl({
                protoPath: '/v1/automation-revisions/{automationId}',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'automation.createdDate' },
                        { path: 'automation.updatedDate' },
                        { path: 'automation.draftUpdatedDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getAutomationRevision;
}
//# sourceMappingURL=automations-v2-automation-automations-service-v-2.http.js.map