import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { EventDefinition } from '@wix/sdk-types';
import { bulkDeleteAutomations as universalBulkDeleteAutomations, copyAutomation as universalCopyAutomation, createAutomation as universalCreateAutomation, createDraftAutomation as universalCreateDraftAutomation, createPreinstalledAutomation as universalCreatePreinstalledAutomation, deleteAutomation as universalDeleteAutomation, deleteDraftAutomation as universalDeleteDraftAutomation, deletePreinstalledAutomation as universalDeletePreinstalledAutomation, getActionsQuotaInfo as universalGetActionsQuotaInfo, getAutomation as universalGetAutomation, getAutomationActionSchema as universalGetAutomationActionSchema, getAutomationRevision as universalGetAutomationRevision, getOrCreateDraftAutomation as universalGetOrCreateDraftAutomation, publishDraftAutomation as universalPublishDraftAutomation, queryAutomations as universalQueryAutomations, queryAutomationsWithDrafts as universalQueryAutomationsWithDrafts, queryPreinstalledAutomationsForApp as universalQueryPreinstalledAutomationsForApp, updateAutomation as universalUpdateAutomation, updateDraftAutomation as universalUpdateDraftAutomation, updatePreinstalledAutomation as universalUpdatePreinstalledAutomation, validateAutomation as universalValidateAutomation, validateAutomationById as universalValidateAutomationById, } from './automations-v2-automation-automations-service-v-2.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/automations' };
export function createAutomation(httpClient) {
    return (automation, options) => universalCreateAutomation(automation, options, 
    // @ts-ignore
    { httpClient });
}
export function getAutomation(httpClient) {
    return (automationId, options) => universalGetAutomation(automationId, options, 
    // @ts-ignore
    { httpClient });
}
export function updateAutomation(httpClient) {
    return (_id, automation, options) => universalUpdateAutomation(_id, automation, options, 
    // @ts-ignore
    { httpClient });
}
export function deleteAutomation(httpClient) {
    return (automationId) => universalDeleteAutomation(automationId, 
    // @ts-ignore
    { httpClient });
}
export function bulkDeleteAutomations(httpClient) {
    return (automationIds) => universalBulkDeleteAutomations(automationIds, 
    // @ts-ignore
    { httpClient });
}
export function createPreinstalledAutomation(httpClient) {
    return (automation, options) => universalCreatePreinstalledAutomation(automation, options, 
    // @ts-ignore
    { httpClient });
}
export function updatePreinstalledAutomation(httpClient) {
    return (automation, options) => universalUpdatePreinstalledAutomation(automation, options, 
    // @ts-ignore
    { httpClient });
}
export function deletePreinstalledAutomation(httpClient) {
    return (componentId, options) => universalDeletePreinstalledAutomation(componentId, options, 
    // @ts-ignore
    { httpClient });
}
export function queryPreinstalledAutomationsForApp(httpClient) {
    return (options) => universalQueryPreinstalledAutomationsForApp(options, 
    // @ts-ignore
    { httpClient });
}
export function queryAutomations(httpClient) {
    return (options) => universalQueryAutomations(options, 
    // @ts-ignore
    { httpClient });
}
export function copyAutomation(httpClient) {
    return (automationId, options) => universalCopyAutomation(automationId, options, 
    // @ts-ignore
    { httpClient });
}
export function createDraftAutomation(httpClient) {
    return (options) => universalCreateDraftAutomation(options, 
    // @ts-ignore
    { httpClient });
}
export function getOrCreateDraftAutomation(httpClient) {
    return (originalAutomationId, options) => universalGetOrCreateDraftAutomation(originalAutomationId, options, 
    // @ts-ignore
    { httpClient });
}
export function updateDraftAutomation(httpClient) {
    return (_id, automation, options) => universalUpdateDraftAutomation(_id, automation, options, 
    // @ts-ignore
    { httpClient });
}
export function queryAutomationsWithDrafts(httpClient) {
    return (options) => universalQueryAutomationsWithDrafts(options, 
    // @ts-ignore
    { httpClient });
}
export function deleteDraftAutomation(httpClient) {
    return (automationId) => universalDeleteDraftAutomation(automationId, 
    // @ts-ignore
    { httpClient });
}
export function publishDraftAutomation(httpClient) {
    return (automationId, options) => universalPublishDraftAutomation(automationId, options, 
    // @ts-ignore
    { httpClient });
}
export function validateAutomation(httpClient) {
    return (automation, options) => universalValidateAutomation(automation, options, 
    // @ts-ignore
    { httpClient });
}
export function validateAutomationById(httpClient) {
    return (automationId, options) => universalValidateAutomationById(automationId, options, 
    // @ts-ignore
    { httpClient });
}
export function getAutomationActionSchema(httpClient) {
    return (identifiers) => universalGetAutomationActionSchema(identifiers, 
    // @ts-ignore
    { httpClient });
}
export function getActionsQuotaInfo(httpClient) {
    return () => universalGetActionsQuotaInfo(
    // @ts-ignore
    { httpClient });
}
/** @internal */
export function getAutomationRevision(httpClient) {
    return (automationId, options) => universalGetAutomationRevision(automationId, options, 
    // @ts-ignore
    { httpClient });
}
export const onAutomationCreated = EventDefinition('wix.automations.v2.automation_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.draftUpdatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onAutomationDeleted = EventDefinition('wix.automations.v2.automation_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.draftUpdatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onAutomationDeletedWithEntity = EventDefinition('wix.automations.v2.automation_deleted_with_entity', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.automation.createdDate' },
            { path: 'data.automation.updatedDate' },
            { path: 'data.automation.draftUpdatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onAutomationUpdated = EventDefinition('wix.automations.v2.automation_updated', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'entity.createdDate' },
            { path: 'entity.updatedDate' },
            { path: 'entity.draftUpdatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export const onAutomationUpdatedWithPreviousEntity = EventDefinition('wix.automations.v2.automation_updated_with_previous_entity', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [
            { path: 'data.previousAutomation.createdDate' },
            { path: 'data.previousAutomation.updatedDate' },
            { path: 'data.previousAutomation.draftUpdatedDate' },
            { path: 'data.currentAutomation.createdDate' },
            { path: 'data.currentAutomation.updatedDate' },
            { path: 'data.currentAutomation.draftUpdatedDate' },
            { path: 'metadata.eventTime' },
        ],
    },
])))();
export { ActionErrorType, AutomationErrorType, AutomationValidationErrorValidationErrorType, DeleteStatus, Domain, Namespace, Operator, Origin, RequestedFields, SiteCreatedContext, SortOrder, State, Status, TimeUnit, TriggerErrorType, TriggerValidationErrorValidationErrorType, Type, ValidationErrorSeverity, ValidationErrorType, WebhookIdentityType, } from './automations-v2-automation-automations-service-v-2.universal.js';
//# sourceMappingURL=automations-v2-automation-automations-service-v-2.public.js.map